# Generated by ariadne-codegen
# Source: /app/operations

from typing import Any, Dict, List, Optional, Union

from .async_base_client import AsyncBaseClient
from .base_model import UNSET, UnsetType
from .input_types import work_sites_bool_exp, work_sites_order_by
from .work_site_detail import WorkSiteDetail
from .work_site_detail_ticket_activity import WorkSiteDetailTicketActivity
from .work_site_ownership import WorkSiteOwnership
from .work_site_search import WorkSiteSearch


def gql(q: str) -> str:
    return q


class Client(AsyncBaseClient):
    async def work_site_search(
        self,
        where: work_sites_bool_exp,
        query: Union[Optional[str], UnsetType] = UNSET,
        order_by: Union[Optional[List[work_sites_order_by]], UnsetType] = UNSET,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> WorkSiteSearch:
        _query = gql(
            """
            query WorkSiteSearch($query: String, $where: work_sites_bool_exp!, $orderBy: [work_sites_order_by!], $limit: Int, $offset: Int) {
              search_work_sites(
                args: {_query: $query}
                where: $where
                order_by: $orderBy
                limit: $limit
                offset: $offset
              ) {
                ...WorkSitesView
              }
              search_work_sites_aggregate(args: {_query: $query}, where: $where) {
                aggregate {
                  count
                }
              }
            }

            fragment CustomerLink on customers {
              id
              abbreviation
              title
            }

            fragment UserLink on users {
              id
              fname
              lname
            }

            fragment WorkSitesView on work_sites {
              author {
                id
                full_name
                ...UserLink
              }
              title
              created_at
              deleted_at
              updated_at
              id
              confirmed_at
              county
              state
              lat
              lng
              api
              current_customer {
                accounting_id
                customer {
                  id
                  title
                  abbreviation
                  ...CustomerLink
                }
              }
              order_items_aggregate {
                aggregate {
                  count
                }
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "query": query,
            "where": where,
            "orderBy": order_by,
            "limit": limit,
            "offset": offset,
        }
        response = await self.execute(
            query=_query, operation_name="WorkSiteSearch", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return WorkSiteSearch.model_validate(data)

    async def work_site_detail(
        self, work_site_id: Any, **kwargs: Any
    ) -> WorkSiteDetail:
        query = gql(
            """
            query WorkSiteDetail($workSiteId: uuid!) {
              work_sites_by_pk(id: $workSiteId) {
                author {
                  full_name
                  ...UserLink
                }
                created_at
                id
                title
                deleted_at
                county
                state
                lat
                lng
                api
                confirmed_at
                current_customer {
                  accounting_id
                  customer_id
                  customer {
                    title
                    ...CustomerLink
                  }
                }
              }
            }

            fragment CustomerLink on customers {
              id
              abbreviation
              title
            }

            fragment UserLink on users {
              id
              fname
              lname
            }
            """
        )
        variables: Dict[str, object] = {"workSiteId": work_site_id}
        response = await self.execute(
            query=query, operation_name="WorkSiteDetail", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return WorkSiteDetail.model_validate(data)

    async def work_site_ownership(
        self, work_site_id: Any, **kwargs: Any
    ) -> WorkSiteOwnership:
        query = gql(
            """
            query WorkSiteOwnership($workSiteId: uuid!) {
              customers_xref_work_sites(where: {work_site_id: {_eq: $workSiteId}}) {
                id
                started_at
                ended_at
                accounting_id
                customer {
                  id
                  title
                }
              }
            }
            """
        )
        variables: Dict[str, object] = {"workSiteId": work_site_id}
        response = await self.execute(
            query=query,
            operation_name="WorkSiteOwnership",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return WorkSiteOwnership.model_validate(data)

    async def work_site_detail_ticket_activity(
        self, work_site_id: Any, **kwargs: Any
    ) -> WorkSiteDetailTicketActivity:
        query = gql(
            """
            query WorkSiteDetail_TicketActivity($workSiteId: uuid!) {
              ticket_activity(
                where: {ticket: {order_item: {work_site_id: {_eq: $workSiteId}}}, ended_at: {_is_null: false}, _or: [{work_log_id: {_is_null: false}}, {travel_log_id: {_is_null: false}}]}
              ) {
                work_log_id
                travel_log_id
                started_at
                ended_at
                ticket_id
              }
            }
            """
        )
        variables: Dict[str, object] = {"workSiteId": work_site_id}
        response = await self.execute(
            query=query,
            operation_name="WorkSiteDetail_TicketActivity",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return WorkSiteDetailTicketActivity.model_validate(data)
